Type Definition sc_client_api::backend::StateBackendFor [−][src]
pub type StateBackendFor<B, Block> = <B as Backend<Block>>::State;Expand description
Extracts the state backend type for the given backend.
pub type StateBackendFor<B, Block> = <B as Backend<Block>>::State;Extracts the state backend type for the given backend.