[−][src]Module sc_client_api::client
A set of APIs supported by the client along with their primitives.
Structs
| BlockImportNotification | Summary of an imported block |
| ClientInfo | Client info |
| FinalityNotification | Summary of a finalized block. |
| IoInfo | I/O statistics for client instance. |
| MemoryInfo | Memory statistics for client instance. |
| UsageInfo | Usage statistics for running client instance. |
Traits
| BlockBody | Fetch block body by ID. |
| BlockOf | Figure out the block type for a given type (for now, just a |
| BlockchainEvents | A source of blockchain events. |
| ProvideUncles | Provide a list of potential uncle headers for a given block. |
Type Definitions
| BadBlocks | Known bad block hashes. |
| FinalityNotifications | A stream of block finality notifications. |
| ForkBlocks | Expected hashes of blocks at given heights. |
| ImportNotifications | Type that implements |